local EasyMCM = include("easyMCM.EasyMCM")

-- Create a placeholder page if EasyMCM is not installed.
if (EasyMCM == nil) or (EasyMCM.version < 1.4) then
    local function placeholderMCM(element)
        element:createLabel{text="Ce menu requiert Simple MCM v1.4 ou plus rcent pour fonctionner."}
        local link = element:createTextSelect{text="Aller sur la page de tlchargement"}
        link.color = tes3ui.getPalette("link_color")
        link.widget.idle = tes3ui.getPalette("link_color")
        link.widget.over = tes3ui.getPalette("link_over_color")
        link.widget.pressed = tes3ui.getPalette("link_pressed_color")
        link:register("mouseClick", function()
            os.execute("start https://confrerie-des-traducteurs.fr/morrowind/mods/ressources_communes/simple_mcm")
        end)
    end
    mwse.registerModConfig("Fouille rapide", {onCreate=placeholderMCM})
    return
end


-------------------
-- Utility Funcs --
-------------------
local config = require("QuickLoot.config")

local function getContainers()
    local list = {}
    for obj in tes3.iterateObjects(tes3.objectType.container) do
		list[#list+1] = (obj.baseObject or obj).id:lower()
    end
    table.sort(list)
    return list
end

----------------------
-- EasyMCM Template --
----------------------
local template = EasyMCM.createTemplate{name="Fouille rapide"}
template:saveOnClose("Fouille rapide", config)
template:register()

-- Preferences Page
local preferences = template:createSideBarPage{label="Prfrences"}
preferences.sidebar:createInfo{text="Fouille rapide Version 2.01"}

-- Sidebar Credits
local credits = preferences.sidebar:createCategory{label="Crdits :"}
credits:createHyperlink{
    text = "mort - Auteur, scripteur, etc.",
    exec = "start https://www.nexusmods.com/morrowind/users/4138441?tab=user+files",
}
credits:createHyperlink{
    text = "Svengineer99 - Aide pour les scripts",
    exec = "start https://www.nexusmods.com/morrowind/users/1121630?tab=user+files",
}
credits:createHyperlink{
    text = "Greatness7 - Aide pour les scripts et le MCM",
    exec = "start https://www.nexusmods.com/users/64030?tab=user+files",
}
credits:createHyperlink{
    text = "Nullcascade - MWSE",
    exec = "start https://www.nexusmods.com/morrowind/users/26153919?tab=user+files",
}
credits:createHyperlink{
    text = "Hrnchamd - MWSE",
    exec = "start https://www.nexusmods.com/morrowind/users/843673?tab=user+files",
}
credits:createHyperlink{
    text = "PeteTheGoat - Beaucoup de tests",
    exec = "start https://www.nexusmods.com/morrowind/users/25319994",
}


-- Feature Toggles
local toggles = preferences:createCategory{label="Paramtres"}
toggles:createOnOffButton{
    label = "Dsactiver Fouille rapide",
    description = "Par dfaut : dsactiv\n\n",
    variable = EasyMCM:createTableVariable{
        id = "modDisabled",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Afficher les messages indiquant ce que vous avez ramass lors de la fouille",
    description = "Affiche une messagebox standard du jeu chaque fois que vous ramassez un objet via le menu de Fouille rapide.\n\nPar dfaut : dsactiv\n\n",
    variable = EasyMCM:createTableVariable{
        id = "showMessageBox",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Cacher les objets dans les conteneurs pigs",
    description = "Si cette option est dsactive, vous pourrez voir les objets dans le conteneur, mais dclencherez le pige si vous tentez d'en ramasser un.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "hideTrapped",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Cacher le statut de verrouillage des conteneurs",
    description = "Si cette option est dsactive, les conteneurs verrouills afficheront qu'ils le sont dans leur infobulle. Sinon, rien ne sera affich  ce sujet.\n\nPar dfaut : dsactiv\n\n",
    variable = EasyMCM:createTableVariable{
        id = "hideLocked",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Activer le menu de fouille rapide pour les plantes et conteneurs organiques",
    description = "Un conteneur organique est tout conteneur dont le contenu se renouvelle aprs un certain temps, ainsi que les cadavres. Les fonctions de liste noire et liste blanche seront appliques en priorit sur cette option.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "showPlants",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Activer pour les conteneurs dont le script utilise onActivate",
    description = "De nombreux conteneurs possdent des scripts qui utilisent la fonction onActivate pour dterminer quand le joueur interagit avec eux. La plupart du temps, cela ne posera aucun problme, mais il peut arriver que le menu de Fouille rapide casse ces scripts s'il est appliqu  de tels conteneurs. Activer un conteneur manuellement dclenchera correctement le script. Les fonctions de liste noire et liste blanche seront appliques en priorit sur cette option.\n\nPar dfaut : dsactiv\n\n",
    variable = EasyMCM:createTableVariable{
        id = "showScripted",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Cacher les infobulles des conteneurs vanilla",
    description = "Cache l'infobulle qui apparat normalement lorsque votre curseur est plac sur un objet.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "hideTooltip",
        table = config,
    },
}
toggles:createOnOffButton{
    label = "Utiliser la touche \"Activer\" pour prendre un objet",
    description = "Appuyez sur la barre Espace pour ramasser un objet dans le menu de Fouille rapide.\n\nPar dfaut : activ\n\n",
    variable = EasyMCM:createTableVariable{
        id = "activateMode",
        table = config,
    },
}
toggles:createSlider{
    label = "Nombre d'objets affichs par dfaut ",
	min=4,
	max=25,
	jump=2,
    variable = EasyMCM:createTableVariable{
        id = "maxItemDisplaySize",
        table = config,
    },
}
toggles:createSlider{
    label = "Position sur l'axe X du menu (gauche - droite) ",
	max=10,
	jump=1,
    variable = EasyMCM:createTableVariable{
        id = "menuX",
        table = config,
    },
}
toggles:createSlider{
    label = "Position sur l'axe Y (haut - bas) ",
	max=10,
	jump=1,
    variable = EasyMCM:createTableVariable{
        id = "menuY",
        table = config,
    },
}

local keybinds = preferences:createCategory{label="Raccourcis"}
keybinds:createKeyBinder{
    label = "Prendre un objet (\"z\" par dfaut)",
    allowCombinations = true,
    variable = EasyMCM.createTableVariable{
        id = "takeKey",
        table = config,
        defaultSetting = {
            keyCode = tes3.scanCode['z'],
            --These default to false
            isShiftDown = false,
            isAltDown = false,
            isControlDown = false,
        }
    }
}
keybinds:createKeyBinder{
    label = "Tout prendre (\"x\" par dfaut)",
    allowCombinations = true,
    variable = EasyMCM.createTableVariable{
        id = "takeAllKey",
        table = config,
        defaultSetting = {
            keyCode = tes3.scanCode['x'],
            --These default to false
            isShiftDown = false,
            isAltDown = false,
            isControlDown = false,
        }
    }
}
keybinds:createKeyBinder{
    label = "(Ds)activer Fouille rapide (\"x\" par dfaut)",
    allowCombinations = true,
    variable = EasyMCM.createTableVariable{
        id = "svengKey",
        table = config,
        defaultSetting = {
            keyCode = tes3.scanCode['x'],
            --These default to false
            isShiftDown = false,
            isAltDown = false,
            isControlDown = false,
        }
    }
}

-- Blacklist Page
template:createExclusionsPage{
    label = "Liste noire",
    description = "Tous les conteneurs organiques sont traits comme de la flore. Les coffres d'quipement des guildes sont sur liste noire par dfaut, tout comme certains conteneurs issus de TR. D'autres conteneurs peuvent tre ajouts  la liste noire via ce menu.",
    leftListLabel = "Liste noire ",
    rightListLabel = "Objets ",
    variable = EasyMCM:createTableVariable{
        id = "blacklist",
        table = config,
    },
    filters = {
        {callback = getContainers},
    },
}

-- Whitelist Page
template:createExclusionsPage{
    label = "Liste blanche",
    description = "Les conteneurs scripts sont automatiquement ignors, mais vous pouvez forcer leur prise en compte par le mod via ce menu. Les conteneurs modifis par le mod Expanded Sounds de Piratelord sont sur liste blanche par dfaut. Faites attention si vous mettez sur liste blanche des conteneurs dont le script utilise la fonction onActivate, car cela peut casser leur script.",
    leftListLabel = "Liste blanche ",
    rightListLabel = "Objets ",
    variable = EasyMCM:createTableVariable{
        id = "whitelist",
        table = config,
    },
    filters = {
        {callback = getContainers},
    },
}
